@@ -1,8 +1,6 @@
 """Rules for Archipelago."""
 
 from BaseClasses import MultiWorld
-from worlds.AutoWorld import LogicMixin
-from worlds.generic.Rules import add_rule, set_rule
 
 
 def set_rules(world: MultiWorld, player: int):
