@@ -1,18 +1,23 @@
 """Common classes and functions for the N64 client for DK64."""
 
-import asyncio
+from asyncio import Task, create_task
 import urllib.request
 import os
 import pkgutil
 import json
 import sys
+from typing import Any, Coroutine, Set
 from Utils import get_settings
 
 
 def get_ap_version():
     """Get the AP version from the manifest file."""
-    apworld_manifest = json.loads(pkgutil.get_data("worlds.dk64", "archipelago.json").decode("utf-8"))
-    return apworld_manifest["world_version"]
+    maybe_manifest = pkgutil.get_data("worlds.dk64", "archipelago.json")
+    if maybe_manifest:
+        apworld_manifest = json.loads(maybe_manifest.decode("utf-8"))
+        return apworld_manifest["world_version"]
+    else:
+        raise FileNotFoundError("Could not find the AP world manifest file.")
 
 
 class DK64MemoryMap:
@@ -63,10 +68,10 @@ class DK64MemoryMap:
     count_struct_pointer = 0x807FFFB8  # Pointer to CountStruct containing item counts
 
 
-all_tasks = set()
+all_tasks: Set[Task[Any]] = set()
 
 
-def create_task_log_exception(awaitable) -> asyncio.Task:
+def create_task_log_exception(awaitable: Coroutine[Any, Any, None]) -> Task[Any]:
     """Create an asyncio task that logs any exceptions raised during its execution.
 
     Args:
@@ -78,17 +83,16 @@ def create_task_log_exception(awaitable) -> asyncio.Task:
     """
     from CommonClient import logger
 
-    async def _log_exception(awaitable):
+    async def _log_exception(awaitable: Coroutine[Any, Any, None]) -> None:
         try:
-            return await awaitable
+            await awaitable
         except Exception as e:
             logger.exception(e)
             pass
         finally:
             all_tasks.remove(task)
-        return
 
-    task = asyncio.create_task(_log_exception(awaitable))
+    task = create_task(_log_exception(awaitable))
     all_tasks.add(task)
     return task
 
