@@ -455,7 +455,7 @@ fairy_locations = {
         ),
         relocated_5ds_fairy,
         FairyData(
-            name="Tiny Slam Button",
+            name="Tiny Slam Switch",
             map=Maps.GloomyGalleon,
             region=Regions.GloomyGalleonStart,
             fence=Fence(2222, 2659, 2299, 2731),
@@ -483,14 +483,14 @@ fairy_locations = {
             spawn_y=1707,
         ),
         FairyData(
-            name="Inbetween 5-Door Ship and 2-Door Ship",
+            name="Towards the 2-Door Ship",
             map=Maps.GloomyGalleon,
             region=Regions.ShipyardUnderwater,
             fence=Fence(1628, 1883, 1746, 2235),
             spawn_y=1220,
         ),
         FairyData(
-            name="Inbetween 5-Door Ship and Seal Race",
+            name="Towards the Seal Race",
             map=Maps.GloomyGalleon,
             region=Regions.ShipyardUnderwater,
             fence=Fence(2691, 441, 3345, 1305),
@@ -973,7 +973,7 @@ fairy_locations = {
             spawn_y=300,
         ),
         FairyData(
-            name="Above Donkey Diddy Chunky Crypt Entrance",
+            name="Above entrance to Crypt",
             map=Maps.CastleLowerCave,
             region=Regions.LowerCave,
             fence=Fence(134, 1173, 702, 1293),
